@@ -94,10 +94,14 @@ class MediaHandler:
             thumbnail_path = self._generate_thumbnail(target_path, entity_type, entity_id)
         
         # Prepare metadata
+        # ⚠️ IMPORTANT: Store RELATIVE path from base_media_path for web server compatibility
+        # Web server serves media from /media/ route, so paths should be: media/images/...
+        relative_path = target_path.relative_to(self.base_media_path.parent)
+
         metadata = {
             'media_name': source_path.name,
             'media_filename': unique_filename,
-            'media_path': str(target_path),
+            'media_path': str(relative_path),  # Relative path: media/images/site_X/file.jpg
             'media_type': file_info['media_type'],
             'mime_type': file_info['mime_type'],
             'file_size': file_info['file_size'],
@@ -108,9 +112,9 @@ class MediaHandler:
             'height': file_info.get('height'),
             'entity_type': entity_type,
             'entity_id': entity_id,
-            'thumbnail_path': str(thumbnail_path) if thumbnail_path else None
+            'thumbnail_path': str(thumbnail_path.relative_to(self.base_media_path.parent)) if thumbnail_path else None
         }
-        
+
         return metadata
     
     def _analyze_file(self, file_path: Path) -> Dict[str, Any]:
