@@ -221,24 +221,8 @@ class ExtendedMatrixExcelParser:
             DataFrame with Excel data
         """
         try:
-            # Suppress all warnings during Excel loading
-            with warnings.catch_warnings():
-                warnings.simplefilter("ignore")
-
-                # Also redirect stderr at file descriptor level for C library warnings
-                import tempfile
-                null_fd = os.open(os.devnull, os.O_RDWR)
-                old_stderr_fd = os.dup(2)
-                os.dup2(null_fd, 2)
-
-                try:
-                    self.df = pd.read_excel(self.excel_path)
-                    self.statistics['total_rows'] = len(self.df)
-                finally:
-                    # Restore stderr
-                    os.dup2(old_stderr_fd, 2)
-                    os.close(old_stderr_fd)
-                    os.close(null_fd)
+            self.df = pd.read_excel(self.excel_path)
+            self.statistics['total_rows'] = len(self.df)
 
             logger.info(f"✓ Loaded {len(self.df)} rows from {self.excel_path.name}")
             print(f"✓ Loaded {len(self.df)} rows from {self.excel_path.name}")
@@ -652,40 +636,61 @@ class ExtendedMatrixExcelParser:
         print(f"File: {self.excel_path.name}")
         print(f"Site: {self.site_name}")
         print(f"{'='*60}\n")
+        sys.stdout.flush()
+
+        # Redirect ONLY stderr to suppress pandas/openpyxl warnings (keep stdout for progress messages)
+        import tempfile
+        null_fd = os.open(os.devnull, os.O_RDWR)
+        old_stderr_fd = os.dup(2)
 
         try:
-            # Step 1: Initialize database
-            self.init_database()
+            # Suppress Python warnings
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
 
-            # Step 2: Load Excel
-            self.load_excel()
+                # Redirect ONLY stderr at OS level (for C library warnings from pandas/openpyxl)
+                # Keep stdout open for progress messages
+                os.dup2(null_fd, 2)
 
-            # Step 3: Ensure site exists
-            self.ensure_site_exists()
+                try:
+                    # Step 1: Initialize database
+                    self.init_database()
 
-            # Step 3: Import US records
-            self.import_us_records()
+                    # Step 2: Load Excel
+                    self.load_excel()
 
-            # Step 4: Import relationships
-            self.import_relationships()
+                    # Step 3: Ensure site exists
+                    self.ensure_site_exists()
 
-            # Step 5: Update rapporti field in US records
-            self.update_rapporti_field()
+                    # Step 3: Import US records
+                    self.import_us_records()
 
-            # Step 6: Generate GraphML (optional)
-            graphml_path = None
-            if generate_graphml:
-                # Build output path
-                if output_dir:
-                    os.makedirs(output_dir, exist_ok=True)
-                    output_path = os.path.join(output_dir, f"{self.site_name.replace(' ', '_')}_extended_matrix.graphml")
-                else:
-                    output_path = None
+                    # Step 4: Import relationships
+                    self.import_relationships()
 
-                graphml_path = self.generate_graphml(output_path=output_path, reverse_edges=reverse_edges)
-                self.statistics['graphml_path'] = graphml_path
+                    # Step 5: Update rapporti field in US records
+                    self.update_rapporti_field()
 
-            # Print summary
+                    # Step 6: Generate GraphML (optional)
+                    graphml_path = None
+                    if generate_graphml:
+                        # Build output path
+                        if output_dir:
+                            os.makedirs(output_dir, exist_ok=True)
+                            output_path = os.path.join(output_dir, f"{self.site_name.replace(' ', '_')}_extended_matrix.graphml")
+                        else:
+                            output_path = None
+
+                        graphml_path = self.generate_graphml(output_path=output_path, reverse_edges=reverse_edges)
+                        self.statistics['graphml_path'] = graphml_path
+
+                finally:
+                    # Restore stderr
+                    os.dup2(old_stderr_fd, 2)
+                    os.close(old_stderr_fd)
+                    os.close(null_fd)
+
+            # Print summary (after restoring stderr)
             print(f"\n{'='*60}")
             print(f"Import Summary")
             print(f"{'='*60}")
@@ -704,11 +709,20 @@ class ExtendedMatrixExcelParser:
                 print(f"\n✓ Import completed successfully!")
 
             print(f"{'='*60}\n")
+            sys.stdout.flush()
 
             return self.statistics
 
         except Exception as e:
+            # Restore stderr in case of exception
+            try:
+                os.dup2(old_stderr_fd, 2)
+                os.close(old_stderr_fd)
+                os.close(null_fd)
+            except:
+                pass
             print(f"\n✗ Import failed: {e}")
+            sys.stdout.flush()
             raise
 
 
